==> desk_net-4.0.9.tar.gz: desk_net/src/Form/DeskNetPublicationCustomFieldMatching.php <==
<?php

/**
 * @file
 * The "Publication Custom Field Matching" form.
 */

namespace Drupal\desk_net\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

use Drupal\desk_net\Controller\ModuleSettings;
use Drupal\desk_net\Collection\NoticesCollection;
use Drupal\desk_net\PageTemplate\PageTemplate;
use Drupal\desk_net\Controller\RequestsController;
use Drupal\desk_net\DeleteMethods;

class DeskNetPublicationCustomFieldMatching extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'desk_net_publication_custom_field_matching';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Loading all Drupal Content types from Desk-Net.
    $is_publication_custom_fields_exist = $this->getPublicationCustomFields();
    $config = \Drupal::config('desk_net.settings');
    $configuration_setting_name = 'desk_net_selected_publication_custom_field_matching_list';
    $publication_cf_list = $config->get('desk_net_publication_custom_fields');

    if ($publication_cf_list !== NULL) {
      $publication_cf_list = unserialize($publication_cf_list);
    }

    if (!empty($config->get('platform_id'))) {
      $html = '<h2>' . \Drupal::translation()
          ->translate('Publication Custom Field Matching') . '</h2>';
      $html .= '<p>';
      $html .= \Drupal::translation()
        ->translate('Use this page to match the publication custom fields in Desk-Net 
        with the Title and URL alias in Drupal.');
      $html .= '</p>';

      if ($is_publication_custom_fields_exist && !empty(ModuleSettings::variableGet('desk_net_token'))) {
        $do_not_import = [

        ];
        $drupal_to_desk_net = [
          'title' => [
            'id' => 'title',
            'name' => \Drupal::translation()
              ->translate('Title'),
          ],
          'url_alias' => [
            'id' => 'url_alias',
            'name' => \Drupal::translation()
              ->translate('URL Alias'),
          ],
          'no_publication_cf' => [
            'id' => 'no_publication_cf',
            'name' => \Drupal::translation()
              ->translate('No syncing'),
          ],
        ];

        if (!empty($publication_cf_list)) {
          foreach ($publication_cf_list as $value) {
            $desk_net_to_drupal[$value['id']]['id'] = $value['id'];
            $desk_net_to_drupal[$value['id']]['name'] = $value['name'];
          }
        }

        $html .= '<h4 class="dn_b-title">' . \Drupal::translation()
            ->translate('Desk-Net to Drupal') . '</h4>';

        $form['html'] = [
          '#markup' => $html,
        ];

        $form['desk_net_to_drupal_matching'] = PageTemplate::desk_net_matching_page_template(
          $configuration_setting_name, $desk_net_to_drupal, $drupal_to_desk_net,
          'publication_cf', 'desk_net_to_drupal', 'no_publication_cf');

        $sub_title = '<h4 class="dn_b-title">' . \Drupal::translation()
            ->translate('Drupal to Desk-Net') . '</h4>';

        $form['subTitle'] = [
          '#markup' => $sub_title,
        ];

        unset($drupal_to_desk_net['no_publication_cf']);
        $desk_net_to_drupal['no_publication_cf'] = [
          'id' => 'no_publication_cf',
          'name' => \Drupal::translation()
            ->translate('No syncing'),
        ];

        $form['drupal_to_desk_net_matching'] = PageTemplate::desk_net_matching_page_template(
          $configuration_setting_name, $drupal_to_desk_net, $desk_net_to_drupal,
          'publication_cf', 'drupal_to_desk_net', 'no_publication_cf');

        $form['submit'] = [
          '#type' => 'submit',
          '#value' => \Drupal::translation()->translate('Save'),
        ];

        return $form;
      }
      elseif (!$is_publication_custom_fields_exist && empty($publication_cf_list)) {
        $html .= '<p>';
        $html .= '<strong>' . \Drupal::translation()
            ->translate('Please note:') . '</strong> ';
        $html .= \Drupal::translation()
          ->translate('The synchronized platform in Desk-Net lacks publication custom fields for matching.');
        $html .= '</p>';

        $form['html'] = [
          '#markup' => $html,
        ];

        return $form;
      }
      else {
        \Drupal::messenger()->addError(NoticesCollection::getNotice(9));
      }
    }
    else {
      \Drupal::messenger()->addError(NoticesCollection::getNotice(10));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $formValues = NULL;

    if (!empty($form_state->getValues())) {
      foreach ($form_state->getValues() as $key => $value) {
        if ($key != 'form_id' && $key != 'op' && $key != 'form_token' &&
          $key != 'form_build_id' && $key != 'submit'
        ) {
          $formValues[$key] = $value;
        }
      }

      // Save the values to configuration.
      \Drupal::configFactory()
        ->getEditable('desk_net.settings')
        ->set('desk_net_selected_publication_custom_field_matching_list', serialize($formValues))
        ->save();

      \Drupal::messenger()->addStatus(NoticesCollection::getNotice(13));
    }
  }

  /**
   * Perform get Types for Desk-Net platform.
   *
   * @return bool
   *   The result loading types list from Desk-Net.
   */
  private function getPublicationCustomFields() {
    $config = \Drupal::config('desk_net.settings');
    $configFactory = \Drupal::configFactory()->getEditable('desk_net.settings');
    $platform_id = $config->get('platform_id');
    $saved_publication_cf_list = $config->get('desk_net_publication_custom_fields');

    if ($saved_publication_cf_list !== NULL) {
      $saved_publication_cf_list = unserialize($saved_publication_cf_list);
    }

    if (!empty($platform_id)) {
      $new_publication_cf_list = (new RequestsController())->get(ModuleSettings::DN_BASE_URL,
        'publication-custom-fields', NULL, 'v1_0_0');

      if ($new_publication_cf_list === 'unauthorized') {
        \Drupal::messenger()->addError(NoticesCollection::getNotice(3));

        return FALSE;
      }

      $new_publication_cf_list = json_decode($new_publication_cf_list, TRUE);
      $new_publication_cf_list = array_filter($new_publication_cf_list, function($item) {
        return isset($item['active']) && $item['active'] === TRUE && $item['type'] === 1;
      });

      if (empty($new_publication_cf_list)) {
        $configFactory->set('desk_net_publication_custom_fields', serialize($new_publication_cf_list))
          ->save();
        return FALSE;
      }

      if (!empty($new_publication_cf_list['message']) || $new_publication_cf_list === 'not_show_new_notice') {
        return FALSE;
      }

      if (!empty($saved_publication_cf_list)) {
        $drupal_sync_field_list = [
          'title',
          'url_alias',
          'no_publication_cf',
        ];

        DeleteMethods::shapeDeletedItems('desk_net_selected_publication_custom_field_matching_list', $new_publication_cf_list,
          $saved_publication_cf_list, $drupal_sync_field_list, 'publication_cf');
      }

      $configFactory->set('desk_net_publication_custom_fields', serialize($new_publication_cf_list))
        ->save();

      return TRUE;
    }

    return FALSE;
  }

}

==> desk_net-4.0.10.tar.gz: desk_net/src/Form/DeskNetPublicationCustomFieldMatching.php <==
<?php

/**
 * @file
 * The "Publication Custom Field Matching" form.
 */

namespace Drupal\desk_net\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

use Drupal\desk_net\Controller\ModuleSettings;
use Drupal\desk_net\Collection\NoticesCollection;
use Drupal\desk_net\PageTemplate\PageTemplate;
use Drupal\desk_net\Controller\RequestsController;
use Drupal\desk_net\DeleteMethods;

class DeskNetPublicationCustomFieldMatching extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'desk_net_publication_custom_field_matching';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Loading all Drupal Content types from Desk-Net.
    $is_publication_custom_fields_exist = $this->getPublicationCustomFields();
    $config = \Drupal::config('desk_net.settings');
    $configuration_setting_name = 'desk_net_selected_publication_custom_field_matching_list';
    $publication_cf_list = $config->get('desk_net_publication_custom_fields');

    if ($publication_cf_list !== NULL) {
      $publication_cf_list = unserialize($publication_cf_list);
    }

    if (!empty($config->get('platform_id'))) {
      $html = '<h2>' . \Drupal::translation()
          ->translate('Publication Custom Field Matching') . '</h2>';
      $html .= '<p>';
      $html .= \Drupal::translation()
        ->translate('Use this page to match the publication custom fields in Desk-Net 
        with the Title and URL alias in Drupal.');
      $html .= '</p>';

      if ($is_publication_custom_fields_exist && !empty(ModuleSettings::variableGet('desk_net_token'))) {
        $drupal_to_desk_net = [
          'title' => [
            'id' => 'title',
            'name' => \Drupal::translation()
              ->translate('Title'),
          ],
          'url_alias' => [
            'id' => 'url_alias',
            'name' => \Drupal::translation()
              ->translate('URL Alias'),
          ],
          'no_publication_cf' => [
            'id' => 'no_publication_cf',
            'name' => \Drupal::translation()
              ->translate('No Sync'),
          ],
        ];

        if (!empty($publication_cf_list)) {
          foreach ($publication_cf_list as $value) {
            $desk_net_to_drupal[$value['id']]['id'] = $value['id'];
            $desk_net_to_drupal[$value['id']]['name'] = $value['name'];
          }
        }

        $html .= '<h4 class="dn_b-title">' . \Drupal::translation()
            ->translate('Desk-Net to Drupal') . '</h4>';

        $form['html'] = [
          '#markup' => $html,
        ];

        $form['desk_net_to_drupal_matching'] = PageTemplate::desk_net_matching_page_template(
          $configuration_setting_name, $desk_net_to_drupal, $drupal_to_desk_net,
          'publication_cf', 'desk_net_to_drupal', 'no_publication_cf');

        $sub_title = '<h4 class="dn_b-title">' . \Drupal::translation()
            ->translate('Drupal to Desk-Net') . '</h4>';

        $form['subTitle'] = [
          '#markup' => $sub_title,
        ];

        unset($drupal_to_desk_net['no_publication_cf']);
        $desk_net_to_drupal['no_publication_cf'] = [
          'id' => 'no_publication_cf',
          'name' => \Drupal::translation()
            ->translate('No Sync'),
        ];

        $form['drupal_to_desk_net_matching'] = PageTemplate::desk_net_matching_page_template(
          $configuration_setting_name, $drupal_to_desk_net, $desk_net_to_drupal,
          'publication_cf', 'drupal_to_desk_net', 'no_publication_cf');

        $form['submit'] = [
          '#type' => 'submit',
          '#value' => \Drupal::translation()->translate('Save'),
        ];

        return $form;
      }
      elseif (!$is_publication_custom_fields_exist && empty($publication_cf_list)) {
        $html .= '<p>';
        $html .= '<strong>' . \Drupal::translation()
            ->translate('Please note:') . '</strong> ';
        $html .= \Drupal::translation()
          ->translate('The synchronized platform in Desk-Net lacks publication custom fields for matching.');
        $html .= '</p>';

        $form['html'] = [
          '#markup' => $html,
        ];

        return $form;
      }
      else {
        \Drupal::messenger()->addError(NoticesCollection::getNotice(9));
      }
    }
    else {
      \Drupal::messenger()->addError(NoticesCollection::getNotice(10));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $formValues = NULL;

    if (!empty($form_state->getValues())) {
      foreach ($form_state->getValues() as $key => $value) {
        if ($key != 'form_id' && $key != 'op' && $key != 'form_token' &&
          $key != 'form_build_id' && $key != 'submit'
        ) {
          $formValues[$key] = $value;
        }
      }

      // Save the values to configuration.
      \Drupal::configFactory()
        ->getEditable('desk_net.settings')
        ->set('desk_net_selected_publication_custom_field_matching_list', serialize($formValues))
        ->save();

      \Drupal::messenger()->addStatus(NoticesCollection::getNotice(13));
    }
  }

  /**
   * Perform get Types for Desk-Net platform.
   *
   * @return bool
   *   The result loading types list from Desk-Net.
   */
  private function getPublicationCustomFields() {
    $config = \Drupal::config('desk_net.settings');
    $configFactory = \Drupal::configFactory()->getEditable('desk_net.settings');
    $platform_id = $config->get('platform_id');
    $saved_publication_cf_list = $config->get('desk_net_publication_custom_fields');

    if ($saved_publication_cf_list !== NULL) {
      $saved_publication_cf_list = unserialize($saved_publication_cf_list);
    }

    if (!empty($platform_id)) {
      $new_publication_cf_list = (new RequestsController())->get(ModuleSettings::DN_BASE_URL,
        'publication-custom-fields', NULL, 'v1_0_0');

      if ($new_publication_cf_list === 'unauthorized') {
        \Drupal::messenger()->addError(NoticesCollection::getNotice(3));

        return FALSE;
      }

      $new_publication_cf_list = json_decode($new_publication_cf_list, TRUE);
      $new_publication_cf_list = array_filter($new_publication_cf_list, function($item) {
        return isset($item['active']) && $item['active'] === TRUE && $item['type'] === 1;
      });

      if (empty($new_publication_cf_list)) {
        $configFactory->set('desk_net_publication_custom_fields', serialize($new_publication_cf_list))
          ->save();
        return FALSE;
      }

      if (!empty($new_publication_cf_list['message']) || $new_publication_cf_list === 'not_show_new_notice') {
        return FALSE;
      }

      if (!empty($saved_publication_cf_list)) {
        $drupal_sync_field_list = [
          'title',
          'url_alias',
          'no_publication_cf',
        ];

        DeleteMethods::shapeDeletedItems('desk_net_selected_publication_custom_field_matching_list', $new_publication_cf_list,
          $saved_publication_cf_list, $drupal_sync_field_list, 'publication_cf');
      }

      $configFactory->set('desk_net_publication_custom_fields', serialize($new_publication_cf_list))
        ->save();

      return TRUE;
    }

    return FALSE;
  }

}
